AERI Field Electronics Calibration
==================================

A Jupiter notebook that walks the user through the field electronics calibration
procedure for an AERI and performs all calculations. Functional for MacOS and
Windows (MacOS preffered)

Dockerize
---------

- git clone -b dockerize https://gitlab.ssec.wisc.edu/aeri/field_cal.git
- cd field_cal
- docker rmi field_cal
	- Remove previous field_cal container if it exists
- docker build -t field_cal .
- docker run --rm -p 8888:8888 -v $PWD/field_cal_MM-DD-YYYY_cals:/field_cal_MM-DD-YYYY_cals -v $PWD/field_electronics_calibration:/field_electronics_calibration -it field_cal
	- Update MM-DD-YYYY to the date of the electronics calibration you are running.
	- If the directory is not there it will be created. 
	- Place your collected CAL and CHK files in the field_cal/field_cal_MM-DD-YYYY_cals directory.
- The above command will print output in the terminal that ends with instruction to go to a url.
- go to the url that looks similar to this "http://127.0.0.1:8888/?token=733a13f0f9d60b82a558f84dcee4dc52176e685af0543ea9"
- open Walkthrough.ipynb and begin

Note: color_html.py is in the docker image's environment

Usage
-----

If you do not have Conda, please download it. It is required for the software
to run
- MacOS install: https://docs.anaconda.com/anaconda/install/mac-os
- Windows install: https://docs.anaconda.com/anaconda/install/windows

To get this walkthrough off of git, run
`git clone https://gitlab.ssec.wisc.edu/aeri/field_cal.git` in the terminal

Setup the notebook if you have not done so
(instructions in the ‘Setup’ section below). This only needs to be done once

To run the notebook (Note: some terminal commands may be different on Windows):
1. Open a terminal window and navigate to the main directory you downloaded
(default is field_cal)
- Navigate to the field_electronics_calibration directory: Run
`cd field_electronics_calibration` in terminal
    - You may run `ls` to display directories that you can go to
- Open the web browser you plan on running the notebook in
(instructions in the ‘Suggested Web Browsers’ section below)
- Run `run.sh` in terminal
    - That terminal window will now be unresponsive to most normal terminal
commands
- A browser window will open with the tab at the top labeled 'walkthrough'
    - If the tab at the top is labeled 'JupyterLab', restart your computer and
retry these steps
- Click the first cell and read the directions
- To (un)expand graph output:
    1. Hover over the left side of the graph window, past where the rest of the
notebook cuts off
    - Part of the window will turn grey (in a rectangle)
    - Click the grey box to expand/unexpand the displayed graphs
    - Double click the grey box to hide/show the displayed graphs
- Save a PDF of the notebook when its ready to be saved
(instructions in the ‘Saving as PDF’ section below)
- Shutdown the notebook
    - While in the terminal your notebook is running in:
        1. Press Ctrl-C (hold control then press c)
        - Agree by typing `y` (for yes) then press enter

For additional commands and flags, type `run.sh --help`

Setup
-----

In the main directory (default is field_cal), run:
1. `conda install -y python=3.6.5 jupyter scipy psutil pandas matplotlib`
in terminal
- `pip install -e .` in terminal

List of required dependencies (the above commands should take care of them):
- python (3.6.5 suggested)
- ipython
- numpy
- scipy
- psutil
- pandas
- matplotlib
- widgetsnbextension (2.0.0 required)
- ipywidgets
- uncertainties

To install a specific package version, run `package=x.x.x` for conda install,
and `package==x.x.x` for pip install in terminal. Example: conda install
python=3.6.5

To check the version of a package, run `conda list | grep package_name` or
`pip list | grep package_name` in terminal to pull up the given package name
and its version currently installed.
- `conda list` and `pip list` will pull up every package they have installed
with their respective version.

Suggested Web Browsers
----------------------

1. Google Chrome
- Firefox

- The notebook will default to your default web browser
- Google Chrome is most suggested
- If neither of these are your default web browser, adding
`--browser firefox` or `--browser chrome` to the `run.sh` command
above will run the notebook in said browser (Assuming they are downloaded on
your machine). Example: `run.sh --browser chrome` will run the notebook in
Google Chrome

Saving as PDF
-------------

Note: Print prefferences are different between MacOS and Windows, and between
different web browsers. The below is only for Google Chrome and Firefox on
a MacOS

1. Click 'File' located on the top toolbar in the notebook
- Hover over 'Download as' and click 'HTML (.html)'
- Now, you may either:
    1. Open another terminal window: Right click the terminal icon on the very
bottom toolbar and click 'New Window'
    - Shutdown the notebook if all data has been recorded and use that terminal
- In terminal, run `color_html.py path/to/your/notebook.html` where
'path/to/your/notebook.html' is the path to the HTML file you just dowloaded
- Open the 'Walkthrough_color.html' created from the above command
(located in the same directory as the original HTML), prefferably with Google
Chrome, and a window will open with an image of the notebook.
- Note: What's important when getting a pdf of the notebook is that all
information in the notebook is clearly visible (no clipped cells or graphs).
The following is just a guideline for achieving a good looking pdf
    - For Chrome:
        1. While inside the new window, click Command+P (Mac) or Ctrl+P
(Windows) to pull up a print options window
        - Make 'Destination'='Save as PDF' by clicking the 'Change...' button
 near the top of the print window and clicking 'Save as PDF'
        - Click the 'More settings' tab on the left and verify that:
'Layout'='Portrait', 'Paper size'='Letter', 'Margins'='Default', 'Scale'=95
(instead of 100)
        - Click the 'Save' button located in the top left of the print window
        - At the top of the new window, name the PDF the same way you named
your CAL## and CHK## directory: 'field_cal_MM-DD-YYYY'
        - Click the 'Save' button located at the bottom-right side of the window
        - You now have a PDF of the notebook to save in your documentation
    - For Firefox:
        1. While inside the new window, click Command+P (Mac) or Ctrl+P
(Windows) to pull up a print options window
        - You may need to click the 'Show Details' button on the bottom left
side of the print window so that it says it says 'Hide Deatils', and the window
is expanded
        - Check that 'Paper Size:' is set to 'US Letter'
            - If it is not, click on the the box to the right of 'Paper Size:'
            - Click 'US Letter', which should be at the bottom of the list
        - Make sure that the 'Ignore Scaling and Shrink To Fit Page Width'
option under 'Options:', located about halfway down the window, is checked
        - Click the bottom left button in the window, likely named 'PDF', and
choose 'Save as PDF...'
        - At the top of the new window, name the PDF the same way you named
your CAL## and CHK## directory: 'field_cal_MM-DD-YYYY'
        - Click the 'Save' button located at the bottom-right side of the window
        - You now have a PDF of the notebook to save in your documentation


Developer/Editing Instructions
------------------------------

To allow notebook edits, add the tag `-e` to your `run.sh` command
- This will pull up a window with all files in field_electronics_calibration,
allowing you to pick which notebook you would like to open
- While running `jupyter notebook` is similar, `run.sh -e` will change cells to
be editable and deletable.
- Note: All other commands and flags that work for `jupyter notebook` will work
for `run.sh` and `run.sh -e` in any order

Short editing guide:
- Click (or double click) on a cell and start typing to edit
- On the top toolbar, 'View' then 'Toggle Header' and 'Toggle Toolbar' will
hide and show the top
user interface bars
- 'Edit' allows you to delete, move, etc cells
- 'File' then 'Save and Checkpoint' saves the notebook
- The 'Markdown' or 'Cell' pulldown box will allow you to change cells between
code and text
- Lots lots more. Play and around and research more at the official
documentation on notebooks:
https://jupyter-notebook.readthedocs.io/en/stable/notebook.html

If `run.sh -e` is not allowing edits:
1. run the notebook through `jupyter notebook` in terminal
- Go to the notebook you are working on
- Click the “View” option at the top left side of the screen
- Go to “Cell Toolbar” and click on “Edit Metadata”. This will bring up a box in
the top-right of every cell in the notebook labeled “Edit Metadata”
- Click the “Edit Metadata” box. A window will pop up that allows you to see
and type properties about the cell
- Delete both ’“editable”: false’ and ‘“deletable”: false’
- Click the "Edit" button on the bottom right to save changes
- That cell should now be editable and deletable
- Repeat for any cell you wish to change
- Note: field_electronics_calibration/security.py makes cells uneditable

Contact With Questions
----------------------

If there are any questions regarding the notebook, please email Will
Roberts at wroberts4@wisc.edu or Denny Hackel at denny.hackel@ssec.wisc.edu
