#!/usr/bin/env bash

# Program called to start notebooks
echo ''
echo 'START========Walkthrough========START'
echo '-------------------------------------'
echo ''

# Note: this will always run correctly if field_electronics_calibration's name is changed.
if [ ${PWD:${#PWD}-29:${#PWD}} != 'field_electronics_calibration' ] ; then
    echo '                ERROR                '
    echo ''
    echo '-------------------------------------'
    echo '[E '"`date +%H:%M:%S`"' Run] You must be in the field_electronics_calibration directory'
    echo '[E '"`date +%H:%M:%S`"' Run] Please refer to the README.md'
    echo '[E '"`date +%H:%M:%S`"' Run] You are in '$PWD
    echo '-------------------------------------'
    echo 'END==========Walkthrough==========END'
    echo ''
    exit 10
fi

echo '                SETUP                '
echo ''
echo '-------------------------------------'

# Run with all args. If secure.py does not exist, exit emediately.
python secure.py $* || {
echo '[E '"`date +%H:%M:%S`"' Run] An error has occured' && echo '[E '"`date +%H:%M:%S`"' Run] Terminating notebook' &&
exit 10
}

echo '-------------------------------------'
echo ''
echo '              NOTEBOOK               '
echo ''
echo '-------------------------------------'

# Find if '-e' or '--help' flags were provided
editable=false
help=false
for arg in $*
do
    if [ $arg == '--help' ] || [ $arg == '--help-all' ] ; then
        editable=false
        help=true
        break
    fi
    if [ $arg == '-e' ] ; then
        editable=true
    fi
done
# Run notebook to be editable
if [ $editable == 'true' ] ; then
    echo '[I '"`date +%H:%M:%S`"' Run] Running in edit mode'
    # Use all args but '-e' flag since it's only used by secure.py, not the notebook. If an incorrect file is entered
    # in edit mode, then print what happened and shut down program normally.
    jupyter notebook ${*/$'-e'} || {
    echo '[E '"`date +%H:%M:%S`"' Run] Incorrect path to a notebook was entered' && echo '[E '"`date +%H:%M:%S`"' Run]
    Shutting down'
    }
# Run notebook to be uneditable or pull up help interface
else
    if [ $help == 'true' ] ; then
        echo '[I '"`date +%H:%M:%S`"' Run] Running in help mode'
    else
        echo $log'[I '"`date +%H:%M:%S`"' Run] Running in non-edit mode'
    fi
    # Run notebook with all args
    jupyter notebook walkthrough.ipynb $*
    # Help interface.
    if [ $help == 'true' ] ; then
        echo 'Additional Flags'
        echo '----------------'
        echo ''
        echo -en '-e\n'
        echo '    Allow notebooks to be editable'
        echo ''
    fi
fi

echo '-------------------------------------'
echo ''
echo '              TAKEDOWN               '
echo ''
echo '-------------------------------------'

# Run with no args to make uneditable after done.
python secure.py

echo '-------------------------------------'
echo 'END==========Walkthrough==========END'
echo ''

