from subprocess import check_output
import json
import sys
import glob
import logging


# Called by run.sh in order to make notebook uneditable and trusted.
def main():
    while True:
        try:
            logging.getLogger().setLevel(logging.INFO)
            def get_level(int):
                levels = {0: 'O', 10: 'D', 20: 'I', 30: 'W', 40: 'E', 50: 'C'}
                return levels[int]
            logging.basicConfig(format='%(asctime)s.%(msecs)03d Security] %(message)s', datefmt='[{} %H:%M:%S'.
                                format(get_level(logging.getLogger().getEffectiveLevel())))
            error_msg = 'Do not press Ctrl-C, security is shutting down and could corrupt notebooks'
            logging.info('Securing notebooks')
            files = glob.glob('*.ipynb')
            notebook = None
            # prevent ^C (control+C) from corruption data
            while True:
                try:
                    # Make notebooks (un)editable and clean-up empty cells for every notebook in directory
                    for file in files:
                        with open(file, encoding='utf-8') as old_file:
                            notebook = json.load(old_file)
                            cells = notebook['cells']
                            good_cells = []
                            for cell in cells:
                                cell['metadata']['editable'] = '-e' in sys.argv
                                cell['metadata']['deleteable'] = '-e' in sys.argv
                                if cell['source'] != []:
                                    good_cells.append(cell)
                            notebook['cells'] = good_cells
                            try:
                                del notebook['metadata']['celltoolbar']
                            except KeyError:
                                pass
                    break
                except KeyboardInterrupt:
                    logging.critical(error_msg)
            # prevent ^C (control+C) from corruption data
            while True:
                try:
                    # Make notebooks trusted
                    for file in files:
                        with open(file, 'w') as new_file:
                            json.dump(notebook, new_file)
                        # run the code, then get display as a byte string, translate it to a string, then print it without \n.
                        logging.info(check_output(['jupyter', 'trust', file]).decode("utf-8")[:-1])
                    break
                except KeyboardInterrupt:
                    logging.critical(error_msg)
            logging.info('Notebooks secured')
            break
        except KeyboardInterrupt:
            logging.critical(error_msg)


if __name__ == '__main__':
    main()
